;rbsp_efw_spinfit_vxb_subtract_crib.pro
;
;Create the vxb subtracted spinfit data (now from E12 data only)
;
;By Aaron W Breneman
;University of Minnesota
;2013-04-16




date = '2012-10-13'
probe = 'a'
timespan,date

rbspx = 'rbsp'+probe



;Load spice stuff
	rbsp_load_spice_kernels
	rbsp_load_state,probe=probe,/no_spice_load,datatype=['pos','vel','spinper','spinphase','mat_dsc','Lvec'] 

;Load eclipse times 
	rbsp_load_eclipse_predict,probe,date
	get_data,'rbsp'+probe+'_umbra',data=eu
	get_data,'rbsp'+probe+'_penumbra',data=ep


;Load waveform data
	rbsp_load_efw_waveform, probe=probe, datatype = 'esvy', coord = 'uvw',/noclean
	
;Spinfit data and transform to MGSE coordinates
	rbsp_spinfit, rbspx + '_efw_esvy', plane_dim = 0 ; V12
	rbsp_cotrans, rbspx + '_efw_esvy_spinfit', rbspx + '_sfit12_mgse', /dsc2mgse



;Get spin axis pointing direction at a 1-min cadence

	time2=time_double(date) ; first get unix time double for beginning of day

	ntimes = 1440.
	time3 = time_string(time2 + 60.*indgen(ntimes))

	strput,time3,'T',10 ; convert TPLOT time string 'yyyy-mm-dd/hh:mm:ss.msec' to ISO 'yyyy-mm-ddThh:mm:ss.msec'
	cspice_str2et,time3,et2 ; convert ISO time string to SPICE ET

	cspice_pxform,'RBSP'+strupcase(probe)+'_SCIENCE','GSE',et2,pxform

	wsc=dblarr(3,ntimes)
	wsc[2,*]=1d
	wsc_GSE=dblarr(3,ntimes)

	for qq=0l,ntimes-1 do wsc_GSE[*,qq] = pxform[*,*,qq] ## wsc[*,qq]




;Transform velocity data to MGSE
	get_data,rbspx+'_vel_gse',data=tmpp
	wsc_GSE_tmp = [[interpol(wsc_GSE[0,*],time_double(time3),tmpp.x)],$
				   [interpol(wsc_GSE[1,*],time_double(time3),tmpp.x)],$
				   [interpol(wsc_GSE[2,*],time_double(time3),tmpp.x)]]
	rbsp_gse2mgse,rbspx+'_vel_gse',reform(wsc_GSE_tmp),newname=rbspx+'_vel_mgse'




;Find the co-rotation Efield
	rbsp_corotation_efield,probe,date,/no_spice_load


;Subtract off the co-rotation Efield
	get_data,rbspx + '_E_coro_mgse',data=eco
	if is_struct(eco) then dif_data,rbspx + '_sfit12_mgse',rbspx+'_E_coro_mgse',newname=rbspx + '_sfit12_mgse'





	;GSE EMFISIS data already loaded from rbsp_corotation_efield
	;tplot,'Mag_gse'
	
;Transform bfield data to MGSE
	get_data,'Mag_gse',data=tmpp
	wsc_GSE_tmp = [[interpol(wsc_GSE[0,*],time_double(time3),tmpp.x)],$
				   [interpol(wsc_GSE[1,*],time_double(time3),tmpp.x)],$
				   [interpol(wsc_GSE[2,*],time_double(time3),tmpp.x)]]
	rbsp_gse2mgse,'Mag_gse',reform(wsc_GSE_tmp),newname='Mag_mgse'




;vxB subtract the Efield data
	rbsp_vxb_subtract,rbspx+'_vel_mgse','Mag_mgse',rbspx+'_sfit12_mgse'


	split_vec,'Esvy_mgse_vxb_removed'
	ylim,['Esvy_mgse_vxb_removed_y','Esvy_mgse_vxb_removed_z'],-5,5
	tplot,['Esvy_mgse_vxb_removed_y','Esvy_mgse_vxb_removed_z']

	if is_struct(eu) then timebar,eu.x,color=50
	if is_struct(eu) then timebar,eu.x + eu.y,color=50
	if is_struct(ep) then timebar,ep.x,color=80
	if is_struct(ep) then timebar,ep.x + ep.y,color=80



